@@ -67,7 +67,7 @@ class Exceptions:
 
 class CodeStarNotificationsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html)
     """
 
@@ -83,7 +83,7 @@ class CodeStarNotificationsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#can_paginate)
         """
 
@@ -95,14 +95,14 @@ class CodeStarNotificationsClient(BaseClient):
         Resource: str,
         Targets: Sequence["TargetTypeDef"],
         DetailType: DetailTypeType,
-        ClientRequestToken: str = None,
-        Tags: Mapping[str, str] = None,
-        Status: NotificationRuleStatusType = None
+        ClientRequestToken: str = ...,
+        Tags: Mapping[str, str] = ...,
+        Status: NotificationRuleStatusType = ...
     ) -> CreateNotificationRuleResultTypeDef:
         """
         Creates a notification rule for a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.create_notification_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.create_notification_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#create_notification_rule)
         """
 
@@ -110,17 +110,17 @@ class CodeStarNotificationsClient(BaseClient):
         """
         Deletes a notification rule for a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_notification_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_notification_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#delete_notification_rule)
         """
 
     def delete_target(
-        self, *, TargetAddress: str, ForceUnsubscribeAll: bool = None
+        self, *, TargetAddress: str, ForceUnsubscribeAll: bool = ...
     ) -> Dict[str, Any]:
         """
         Deletes a specified target for notifications.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_target)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.delete_target)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#delete_target)
         """
 
@@ -128,50 +128,50 @@ class CodeStarNotificationsClient(BaseClient):
         """
         Returns information about a specified notification rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.describe_notification_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.describe_notification_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#describe_notification_rule)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#generate_presigned_url)
         """
 
     def list_event_types(
         self,
         *,
-        Filters: Sequence["ListEventTypesFilterTypeDef"] = None,
-        NextToken: str = None,
-        MaxResults: int = None
+        Filters: Sequence["ListEventTypesFilterTypeDef"] = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...
     ) -> ListEventTypesResultTypeDef:
         """
         Returns information about the event types available for configuring
         notifications.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_event_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_event_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#list_event_types)
         """
 
     def list_notification_rules(
         self,
         *,
-        Filters: Sequence["ListNotificationRulesFilterTypeDef"] = None,
-        NextToken: str = None,
-        MaxResults: int = None
+        Filters: Sequence["ListNotificationRulesFilterTypeDef"] = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...
     ) -> ListNotificationRulesResultTypeDef:
         """
         Returns a list of the notification rules for an AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_notification_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_notification_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#list_notification_rules)
         """
 
@@ -179,33 +179,33 @@ class CodeStarNotificationsClient(BaseClient):
         """
         Returns a list of the tags associated with a notification rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#list_tags_for_resource)
         """
 
     def list_targets(
         self,
         *,
-        Filters: Sequence["ListTargetsFilterTypeDef"] = None,
-        NextToken: str = None,
-        MaxResults: int = None
+        Filters: Sequence["ListTargetsFilterTypeDef"] = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...
     ) -> ListTargetsResultTypeDef:
         """
         Returns a list of the notification rule targets for an AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_targets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.list_targets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#list_targets)
         """
 
     def subscribe(
-        self, *, Arn: str, Target: "TargetTypeDef", ClientRequestToken: str = None
+        self, *, Arn: str, Target: "TargetTypeDef", ClientRequestToken: str = ...
     ) -> SubscribeResultTypeDef:
         """
         Creates an association between a notification rule and an SNS topic so that the
         associated target can receive notifications when the events described in the
         rule are triggered.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.subscribe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.subscribe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#subscribe)
         """
 
@@ -213,7 +213,7 @@ class CodeStarNotificationsClient(BaseClient):
         """
         Associates a set of provided tags with a notification rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#tag_resource)
         """
 
@@ -223,7 +223,7 @@ class CodeStarNotificationsClient(BaseClient):
         that subscribers to that topic stop receiving notifications when the events
         described in the rule are triggered.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.unsubscribe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.unsubscribe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#unsubscribe)
         """
 
@@ -232,7 +232,7 @@ class CodeStarNotificationsClient(BaseClient):
         Removes the association between one or more provided tags and a notification
         rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#untag_resource)
         """
 
@@ -240,23 +240,23 @@ class CodeStarNotificationsClient(BaseClient):
         self,
         *,
         Arn: str,
-        Name: str = None,
-        Status: NotificationRuleStatusType = None,
-        EventTypeIds: Sequence[str] = None,
-        Targets: Sequence["TargetTypeDef"] = None,
-        DetailType: DetailTypeType = None
+        Name: str = ...,
+        Status: NotificationRuleStatusType = ...,
+        EventTypeIds: Sequence[str] = ...,
+        Targets: Sequence["TargetTypeDef"] = ...,
+        DetailType: DetailTypeType = ...
     ) -> Dict[str, Any]:
         """
         Updates a notification rule for a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Client.update_notification_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Client.update_notification_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/client.html#update_notification_rule)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_event_types"]) -> ListEventTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListEventTypes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listeventtypespaginator)
         """
 
@@ -265,13 +265,13 @@ class CodeStarNotificationsClient(BaseClient):
         self, operation_name: Literal["list_notification_rules"]
     ) -> ListNotificationRulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListNotificationRules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listnotificationrulespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_targets"]) -> ListTargetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/codestar-notifications.html#CodeStarNotifications.Paginator.ListTargets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/paginators.html#listtargetspaginator)
         """
