@@ -30,6 +30,7 @@ __all__ = (
     "NotificationRuleStatusType",
     "TargetStatusType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -46,6 +47,7 @@ NotificationRuleStatusType = Literal["DISABLED", "ENABLED"]
 TargetStatusType = Literal["ACTIVE", "DEACTIVATED", "INACTIVE", "PENDING", "UNREACHABLE"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -78,6 +80,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
@@ -314,10 +317,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -325,3 +330,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_event_types", "list_notification_rules", "list_targets"]
